/***************************************************************
 * Name:      slider.cpp
 * Purpose:   Code for Dialog slider
 * Author:    Salvador Pozo (salvapozo@gmail.com)
 * Created:   2024-12-02
 * Copyright: Salvador Pozo (https://conclase.net)
 * License:
 **************************************************************/

#include "slider.h"

IMPLEMENT_DYNAMIC_CLASS( slValidator, wxValidator )
BEGIN_EVENT_TABLE( slValidator, wxValidator )
END_EVENT_TABLE()

bool slValidator::TransferFromWindow()
{
    try {
        wxSlider *sb = dynamic_cast<wxSlider*>(m_validatorWindow);
        *m_valor = sb->GetValue();
    }
    catch (...) {
        wxFAIL_MSG( _T("slValidator sólo funciona con wxSlider"));
        return false;
    }
    return true;
}

wxBEGIN_EVENT_TABLE(slider, wxDialog)
    EVT_CLOSE(slider::OnClose)
    EVT_SLIDER(idSlider, slider::OnSlider)
wxEND_EVENT_TABLE()

slider::slider(wxWindow *wnd, datosSlider &datos)
    : wxDialog(wnd, -1, _T("Ejemplo de slider")), data(datos)
{
    wxBoxSizer *boxVertical;
    wxBoxSizer *boxHorizontal;

    SetBackgroundColour(wxColour(0x98, 0x98, 0x98));

    boxVertical = new wxBoxSizer(wxVERTICAL);

    boxHorizontal = new wxBoxSizer(wxHORIZONTAL);
    m_slider = new wxSlider(this, idSlider, datos.valor, -100, 100, wxDefaultPosition, wxSize(500,50),
        wxSL_HORIZONTAL | wxSL_AUTOTICKS | wxSL_TOP | wxSL_LABELS | wxSL_SELRANGE, slValidator(&datos.valor));
    boxHorizontal->Add(m_slider, wxSizerFlags().Border());
    boxVertical->Add(boxHorizontal, wxSizerFlags().Border(wxTOP).Right());

    boxVertical->Add(CreateStdDialogButtonSizer(wxOK | wxCANCEL), wxSizerFlags().Border());

    SetSizerAndFit(boxVertical);
    m_slider->SetTickFreq(5);
}

slider::~slider()
{
    //dtor
}

void slider::OnClose(wxCloseEvent& event) {
    Destroy();
}

void slider::OnSlider(wxCommandEvent& event) {
    wxString cad;

    cad << "(" << wxEVT_SLIDER << ") Tipo: " << event.GetInt();
    //wxMessageBox(cad, _T("Respuesta"));
}
