/***************************************************************
 * Name:      wx012Main.cpp
 * Purpose:   Code for Application Frame
 * Author:    Salvador Pozo (salvador@conclase.net)
 * Created:   2024-12-02
 * Copyright: Salvador Pozo (https://conclase.net)
 * License:
 **************************************************************/

#ifdef WX_PRECOMP
#include "wx_pch.h"
#endif

#include "wx012Main.h"

//helper functions
enum wxbuildinfoformat {
    short_f, long_f };

wxString wxbuildinfo(wxbuildinfoformat format)
{
    wxString wxbuild(wxVERSION_STRING);

    if (format == long_f )
    {
#if defined(__WXMSW__)
        wxbuild << _T("-Windows");
#elif defined(__WXMAC__)
        wxbuild << _T("-Mac");
#elif defined(__UNIX__)
        wxbuild << _T("-Linux");
#endif

#if wxUSE_UNICODE
        wxbuild << _T("-Unicode build");
#else
        wxbuild << _T("-ANSI build");
#endif // wxUSE_UNICODE
    }

    return wxbuild;
}

BEGIN_EVENT_TABLE(wx012Frame, wxFrame)
    EVT_CLOSE(wx012Frame::OnClose)
    EVT_MENU(idMenuQuit, wx012Frame::OnQuit)
    EVT_MENU(idMenuAbout, wx012Frame::OnAbout)
    EVT_MENU(idMenuSlider, wx012Frame::OnSlider)
END_EVENT_TABLE()

wx012Frame::wx012Frame(wxFrame *frame, const wxString& title)
    : wxFrame(frame, -1, title), dataSlider(0, 100)
{
    // create a menu bar
    wxMenuBar* mbar = new wxMenuBar();
    wxMenu* fileMenu = new wxMenu(_T(""));
    fileMenu->Append(idMenuSlider, _T("S&lider"), _T("Ejemplo de Slider"));
    fileMenu->Append(idMenuQuit, _T("&Salir\tAlt-F4"), _T("Salir de la aplicación"));
    mbar->Append(fileMenu, _T("&Fichero"));

    wxMenu* helpMenu = new wxMenu(_T(""));
    helpMenu->Append(idMenuAbout, _T("&Sobre\tF1"), _T("Muestra información sobre la aplicación"));
    mbar->Append(helpMenu, _T("&Ayuda"));

    SetMenuBar(mbar);

    // create a status bar with some information about the used wxWidgets version
    CreateStatusBar(2);
    SetStatusText(_("Hola"),0);
    SetStatusText(wxbuildinfo(short_f), 1);
}


wx012Frame::~wx012Frame()
{
}

void wx012Frame::OnClose(wxCloseEvent &event)
{
    Destroy();
}

void wx012Frame::OnQuit(wxCommandEvent &event)
{
    Destroy();
}

void wx012Frame::OnAbout(wxCommandEvent &event)
{
    wxString msg = wxbuildinfo(long_f);
    wxMessageBox(msg, _("Bienvenido a ..."));
}

void wx012Frame::OnSlider(wxCommandEvent& event)
{
    wxString cad;
    slider *dlg = new slider(this, dataSlider);
    dlg->ShowModal();

    cad << "V: " << dataSlider.valor;
    wxMessageBox(cad, _T("Respuesta"));
}
